@@ -3,6 +3,7 @@ mod use_before_unload;
 mod use_click_away;
 mod use_counter;
 mod use_debounce;
+mod use_debounce_effect;
 mod use_debounce_state;
 mod use_default;
 mod use_drag;
@@ -37,6 +38,8 @@ mod use_set;
 mod use_size;
 mod use_state_ptr_eq;
 mod use_swipe;
+mod use_throttle;
+mod use_throttle_state;
 mod use_timeout;
 mod use_title;
 mod use_toggle;
@@ -51,6 +54,7 @@ pub use use_before_unload::*;
 pub use use_click_away::*;
 pub use use_counter::*;
 pub use use_debounce::*;
+pub use use_debounce_effect::*;
 pub use use_debounce_state::*;
 pub use use_default::*;
 pub use use_drag::*;
@@ -85,6 +89,8 @@ pub use use_set::*;
 pub use use_size::*;
 pub use use_state_ptr_eq::*;
 pub use use_swipe::*;
+pub use use_throttle::*;
+pub use use_throttle_state::*;
 pub use use_timeout::*;
 pub use use_title::*;
 pub use use_toggle::*;
